mio Package — mio 0.1.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- mio 0.1.8 documentation »
- API Documentation »

# mio Package

## `mio` Package

A Toy Programming Language written in Python

mio is a Toy Programming Language written in the Python Programming Language.

copyright: | CopyRight (C) 2012-2013 by James Mills

## `errors` Module

exception `mio.errors.` `Error`(*args)

  Bases: `exceptions.Exception`

  Error

exception `mio.errors.` `AttributeError`(*args)

  Bases: `mio.errors.Error`

  AttributeError

exception `mio.errors.` `ImportError`(*args)

  Bases: `mio.errors.Error`

  ImportError

exception `mio.errors.` `IndexError`(*args)

  Bases: `mio.errors.Error`

  IndexError

exception `mio.errors.` `KeyError`(*args)

  Bases: `mio.errors.Error`

  KeyError

exception `mio.errors.` `TypeError`(*args)

  Bases: `mio.errors.Error`

  TypeError

exception `mio.errors.` `StopIteration`(*args)

  Bases: `mio.errors.Error`

  StopIteration

exception `mio.errors.` `UserError`(*args)

  Bases: `mio.errors.Error`

  UserError

## `lexer` Module

`mio.lexer.` `tokval`(tok)

`mio.lexer.` `Spec`(name, value)

`mio.lexer.` `tokenize`(s)

## `main` Module

class `mio.main.` `Options`

  Bases: `object`

  Options Object Container

`mio.main.` `parse_bool_arg`(name, argv)

`mio.main.` `parse_arg`(name, argv)

`mio.main.` `parse_args`(argv)

`mio.main.` `main`(argv)

`mio.main.` `entrypoint`()

  SetupTools Entry Point

## `object` Module

class `mio.object.` `Object`(value=<class 'mio.utils.Null'>, methods=True)

  Bases: `object`

  `attrs`
  `parent`
  `value`
  `traits`
  `behaviors`
  `binding`
  `state`
  `create_methods`()
  `lookup`(name)
  `clone`(value=<class 'mio.utils.Null'>)
  `forward`(key)
  `type`
  `has`(receiver, context, m, key)
  `set`(receiver, context, m, key, value)
  `get`(receiver, context, m, key, default=None)
  `block`(receiver, context, m, *args)
  `getState`(receiver, context, m)
  `getType`(receiver, context, m)
  `hash`(receiver, context, m)
  `id`(receiver, context, m, obj=None)
  `keys`(receiver, context, m)
  `init`(receiver, context, m)
  `primitive`(receiver, context, m, method, *args)
  `evalArg`(receiver, context, m, *args)
  `do`(receiver, context, m, expression)
  `setParent`(receiver, context, m, parent)
  `setValue`(receiver, context, m, value)
  `cmp`(receiver, context, m, other)
  `getRepr`(receiver, context, m)
  `getStr`(receiver, context, m)

## `parser` Module

`mio.parser.` `tokval`(tok)

`mio.parser.` `sometok`(type)

`mio.parser.` `op`(name)

`mio.parser.` `op_`(name)

`mio.parser.` `Spec`(name, value)

`mio.parser.` `make_arguments`(n)

`mio.parser.` `make_message`(n)

`mio.parser.` `is_assignment`(message)

`mio.parser.` `is_operator`(message)

`mio.parser.` `reshuffle`(ms)

`mio.parser.` `make_chain`(messages, all=True)

`mio.parser.` `make_expression`(messages)

`mio.parser.` `make_number`(n)

`mio.parser.` `make_string`(n)

`mio.parser.` `make_terminator`(n)

## `runtime` Module

runtime

`mio.runtime.` `init`(args=[], opts=None)

`mio.runtime.` `types`(name)

`mio.runtime.` `core`(name)

`mio.runtime.` `find`(name)

## `state` Module

class `mio.state.` `Completer`(state)

  Bases: `object`

  `attr_matches`(text)
  `complete`(text, state)
  `display_matches`(substitution, matches, longest_match_length)
  `global_matches`(text)

class `mio.state.` `State`(args=None, opts=None)

  Bases: `object`

  `bootstrap`()
  `eval`(code, receiver=None, context=None, showerror=True, reraise=False)
  `find`(name)
  `fromBoolean`(x)
  `fromDict`(x)
  `fromList`(xs)
  `fromTuple`(xs)
  `frommio`(x, default=None)
  `initialize`()
  `load`(filename, receiver=None, context=None)
  `repl`()
  `runsource`(source)
  `toBoolean`(x)
  `toDict`(x)
  `toList`(xs)
  `toTuple`(xs)
  `tomio`(x, default='None')
  `value`

`mio.state.` `check_parens`(s)

`mio.state.` `print_traceback`(e)

## `trait` Module

class `mio.trait.` `Trait`

  Bases: `mio.object.Object`

  `init`(receiver, context, m)
  `requires`(receiver, context, m, *methods)
  `requirements`(receiver, context, m)

## `utils` Module

`mio.utils.` `default_repr`(o)

`mio.utils.` `format_result`(result)

`mio.utils.` `format_value`(value)

`mio.utils.` `format_method`(f)

`mio.utils.` `format_function`(f)

`mio.utils.` `format_object`(o)

`mio.utils.` `method`(name=None, property=False)

`mio.utils.` `tryimport`(modules, message=None)

class `mio.utils.` `MetaNull`

  Bases: `type`

  Meta Class for Null

class `mio.utils.` `Null`

  Bases: `type`

## `version` Module

Version Module

So we only have to maintain version information in one place!

## Subpackages

- core Package
  - `core` Package
  - `block` Module
  - `continuation` Module
  - `error` Module
  - `exception` Module
  - `ffi` Module
  - `file` Module
  - `generator` Module
  - `importer` Module
  - `message` Module
  - `module` Module
  - `parser` Module
  - `path` Module
  - `range` Module
  - `state` Module
  - `system` Module
- traits Package
  - `traits` Package
  - `adaptable` Module
- types Package
  - `types` Package
  - `boolean` Module
  - `bytes` Module
  - `dict` Module
  - `list` Module
  - `number` Module
  - `string` Module
  - `tuple` Module

### Navigation

- index
- modules |
- next |
- previous |
- mio 0.1.8 documentation »
- API Documentation »